intelmq.bots.experts.generic_db_lookup package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.generic_db_lookup package

## Submodules

## intelmq.bots.experts.generic_db_lookup.expert module

Generic DB Lookup

`intelmq.bots.experts.generic_db_lookup.expert.` `BOT`

  alias of `intelmq.bots.experts.generic_db_lookup.expert.GenericDBLookupExpertBot`

class `intelmq.bots.experts.generic_db_lookup.expert.` `GenericDBLookupExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.SQLBot`

  Fetche data from a database

  `database`: str = 'intelmq'
  `engine`: str = '<postgresql OR sqlite>'
  `host`: str = 'localhost'
  `init`()
  `match_fields` = {'source.asn': 'asn'}
  `overwrite`: bool = False
  `password`: str = '<password>'
  `port`: int = 5432
  `process`()
  `replace_fields` = {'contact': 'source.abuse_contact', 'note': 'comment'}
  `sslmode`: str = 'require'
  `table`: str = 'contacts'
  `user`: str = 'intelmq'

## Module contents